/**
 * Copyright IBM Corp. 2020
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from 'react';
import ContextMenu, { ContextMenuItem, ContextMenuRadioGroup, ContextMenuSelectableItem, ContextMenuDivider } from '../ContextMenu';
import { mount } from 'enzyme';
import { settings } from '@rocketsoftware/carbon-components';
import { describe, expect } from 'window-or-global';
var prefix = settings.prefix;
describe('ContextMenu', function () {
  describe('renders as expected', function () {
    describe('menu', function () {
      it('receives the expected classes when closed', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenu, null));
        var container = wrapper.childAt(0).childAt(0);
        expect(container.hasClass("".concat(prefix, "--context-menu"))).toBe(true);
        expect(container.hasClass("".concat(prefix, "--context-menu--open"))).toBe(false);
      });
      it('receives the expected classes when opened', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenu, {
          open: true
        }));
        var container = wrapper.childAt(0).childAt(0);
        expect(container.hasClass("".concat(prefix, "--context-menu"))).toBe(true);
        expect(container.hasClass("".concat(prefix, "--context-menu--open"))).toBe(true);
      });
    });
    describe('option', function () {
      it('receives the expected classes', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Copy"
        }));
        var container = wrapper.childAt(0).childAt(0);
        expect(container.hasClass("".concat(prefix, "--context-menu-option"))).toBe(true);
      });
      it('renders props.label', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Copy"
        }));
        expect(wrapper.find("span.".concat(prefix, "--context-menu-option__label")).text()).toBe('Copy');
        expect(wrapper.find("span.".concat(prefix, "--context-menu-option__label")).prop('title')).toBe('Copy');
      });
      it('renders props.shortcut when provided', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Copy",
          shortcut: "\u2318C"
        }));
        expect(wrapper.find("div.".concat(prefix, "--context-menu-option__info")).length).toBeGreaterThan(0);
        expect(wrapper.find("div.".concat(prefix, "--context-menu-option__info")).text()).toBe('⌘C');
      });
      it('respects props.disabled', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Copy",
          disabled: true
        }));
        var content = wrapper.find("div.".concat(prefix, "--context-menu-option__content"));
        expect(content.hasClass("".concat(prefix, "--context-menu-option__content--disabled"))).toBe(true);
        expect(wrapper.find("li.".concat(prefix, "--context-menu-option")).prop('aria-disabled')).toBe(true);
      });
      it('supports danger kind', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Delete",
          kind: "danger"
        }));
        var option = wrapper.find(".".concat(prefix, "--context-menu-option"));
        expect(option.hasClass("".concat(prefix, "--context-menu-option--danger"))).toBe(true);
      });
      it('ignores danger kind when it has children', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenu, null, /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Remove",
          kind: "danger"
        }, /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Move to trash"
        }), /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Delete"
        }))));
        var option = wrapper.find(".".concat(prefix, "--context-menu-option")).at(0);
        expect(option.hasClass("".concat(prefix, "--context-menu-option--danger"))).toBe(false);
      });
      it('renders props.children as submenu', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenu, null, /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Format"
        }, /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Bold"
        }), /*#__PURE__*/React.createElement(ContextMenuItem, {
          label: "Italic"
        }))));
        var level1 = wrapper.find("li.".concat(prefix, "--context-menu-option")).at(0);
        expect(level1.find("ul.".concat(prefix, "--context-menu")).length).toBeGreaterThan(0);
      });
    });
    describe('radiogroup', function () {
      it('children have role "menuitemradio"', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenuRadioGroup, {
          label: "Share with",
          items: ['None', 'All']
        }));
        var options = wrapper.find("li.".concat(prefix, "--context-menu-option"));
        expect(options.every('li[role="menuitemradio"]')).toBe(true);
      });
    });
    describe('selectable', function () {
      it('has role "menuitemcheckbox"', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenuSelectableItem, {
          label: "Publish"
        }));
        var container = wrapper.childAt(0);
        expect(container.prop('role')).toBe('menuitemcheckbox');
      });
    });
    describe('divider', function () {
      it('receives the expected classes', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenuDivider, null));
        var container = wrapper.childAt(0);
        expect(container.hasClass("".concat(prefix, "--context-menu-divider"))).toBe(true);
      });
      it('has role "separator"', function () {
        var wrapper = mount( /*#__PURE__*/React.createElement(ContextMenuDivider, null));
        var container = wrapper.childAt(0);
        expect(container.prop('role')).toBe('separator');
      });
    });
  });
});